<?php
namespace App\JsonRpc;

use App\Model\Article;
use App\Model\ArticleData;
use App\Model\Category;
use App\Model\Website;
use App\Model\WebsiteCategory;
use Hyperf\DbConnection\Db;
use Hyperf\RpcServer\Annotation\RpcService;
use App\Tools\Result;
use App\Model\ArticleSurvey;
#[RpcService(name: "NewsService", protocol: "jsonrpc-http", server: "jsonrpc-http")]
class NewsService implements NewsServiceInterface
{

    /**
     * 获取导航池列表
     * @param array $data
     * @return array
     */
    public function getCategoryList(array $data): array
    {
        $where = [];
        if(isset($data['name']) && $data['name']){
            array_push($where, ['category.name','like','%'.$data['name'].'%']);
        }
        if(isset($data['department_id']) && $data['department_id']){
            array_push($where, ['category.department_id','=',$data['department_id']]);
        }
        if(isset($data['city_id']) && $data['city_id']){
            array_push($where, ['category.city_id','=',$data['city_id']]);
        }
        $rep = Category::where($where)
            ->leftJoin('district','category.city_id','district.id')
            ->leftJoin('department','category.department_id','department.id')
            ->select("category.*","district.name as city_name","department.name as department_name")
            ->limit($data['pageSize'])->orderBy("category.sort","desc")->orderByDesc('category.updated_at')->offset(($data['page']-1)*$data['pageSize'])->get();
        $count =  Category::where($where)->count();
        $data = [
            'rows'=>$rep->toArray(),
            'count'=>$count
        ];
        if(empty($rep->toArray())){
            return Result::error("没有导航池数据");
        }
        return Result::success($data);
    }

    /**
     * @param array $data
     * @return array
     */
    public function categoryList(array $data): array
    {
        $where[] = [
            'pid','=',$data['pid']
        ];
        if(isset($data['name'])){
            array_push($where, ['category.name','like','%'.$data['name'].'%']);
        }
        var_dump($where);
       $result =  Category::where($where)->select('category.*','category.id as category_id')->get();
        if(empty($result)){
            return Result::error("没有栏目数据");
        }
        return Result::success($result);
    }
    /**
     * @param array $data
     * @return array
     */
    public function addCategory(array $data): array
    {
        $id = Category::insertGetId($data);
        if(empty($id)){
            return Result::error("添加失败");
        }
        return Result::success(['id'=>$id]);
    }

    /**
     * @param array $data
     * @return array
     */
    public function delCategory(array $data): array
    {
        $categoryList = Category::where(['pid'=>$data['id']])->get();
        var_dump("分类列表：",$data,$categoryList);
        if($categoryList->toArray()){
            return Result::error("分类下面有子分类不能删除");
        }
        $articleList = Article::where(['catid'=>$data['id']])->get();
        var_dump("文章列表：",$articleList);
        if($articleList->toArray()){
            return Result::error("分类下面有资讯不能删除");
        }
        $result = Category::where($data)->delete();
        if(!$result){
            return Result::error("删除失败");
        }
        return Result::success($result);
    }

    /**
     * @param array $data
     * @return array
     */
    public function updateCategory(array $data): array
    {
        $where = [
            'id'=>$data['id']
        ];
        $result = Category::where($where)->update($data);
        if($result){
            return Result::success($result);
        }else{
            return Result::error("更新失败");
        }
    }

    /**
     * 获取导航池信息
     * @param array $data
     * @return array
     */
    public function getCategoryInfo(array $data): array
    {
        $where = [
            'id'=>$data['id']
        ];
        $result = Category::where($where)->first();
        if($result){
            return Result::success($result);
        }else{
            return Result::error("更新失败");
        }
    }
    /**
     * @param array $data
     * @return array
     */
    public function getArticleList(array $data): array
    {
        $where= [];

        if(isset($data['title'])  && $data['title']){
            array_push($where,['article.title','like','%'.$data['title'].'%']);
        }
        if(isset($data['category_name'])  && $data['category_name']){
            array_push($where,['category.name','like','%'.$data['category_name'].'%']);
        }
        if(isset($data['author'])  && $data['author']){
             array_push($where,['article.author','=',$data['author']]);
        }
        if(isset($data['islink'])  && $data['islink']!==""){
            array_push($where,['article.islink','=',$data['islink']]);
        }
        if(isset($data['status']) && $data['status']!==""){
            array_push($where,['article.status','=',$data['status']]);
        }
        
        $rep = Article::where($where)
            ->whereNotIn('article.status',[404])
            ->leftJoin('category','article.catid','category.id')
            ->select("article.*","category.name as category_name")
            ->orderBy("article.id","desc")
            ->limit($data['pageSize'])
            ->offset(($data['page']-1)*$data['pageSize'])->get();
        $count =  Article::where($where)->whereNotIn('article.status',[404])
            ->leftJoin('category','article.catid','category.id')->count();
        $data = [
            'rows'=>$rep->toArray(),
            'count'=>$count
        ];
        if(empty($rep)){
            return Result::error("没有信息数据");
        }
        return Result::success($data);
    }

    /**
     * @param array $data
     * @return array
     */
    public function addArticle(array $data): array
    {
        Db::beginTransaction();
        try{

            $articleData = $data;
            unset($articleData['content']);
            $id = Article::insertGetId($articleData);
            $articleDataContent = [
                'article_id'=>$id,
                'content'=>$data['content']
            ];
            ArticleData::insertGetId($articleDataContent);
            Db::commit();
        } catch(\Throwable $ex){
            Db::rollBack();
            var_dump($ex->getMessage());
            return Result::error("创建失败",0);
        }

        return Result::success(['id'=>$id]);
    }

    /**
     * @param array $data
     * @return array
     */
    public function delArticle(array $data): array
    {
        $result = Article::where($data)->update(['status'=>404]);
        if(!$result){
            return Result::error("删除失败");
        }
        return Result::success($result);
    }

    /**
     * @param array $data
     * @return array
     */
    public function updateArticle(array $data): array
    {
        Db::beginTransaction();
        try{
            $data['cat_arr_id'] = isset($data['cat_arr_id'])?json_encode($data['cat_arr_id']):'';
            $data['tag'] = isset($data['tag'])?json_encode($data['tag']):'';
            $articleData = $data;
            unset($articleData['content']);
            unset($articleData['status_name']);
            unset($articleData['name']);
            unset($articleData['content']);
            unset($articleData['pid_arr']);
            unset($articleData['pid']);
            $id = Article::where(['id'=>$data['id']])->update($articleData);
            $articleDataContent = [
                'content'=>$data['content']
            ];
            ArticleData::where(['article_id'=>$data['id']])->update($articleDataContent);
        } catch(\Throwable $ex){
            Db::rollBack();
            var_dump($ex->getMessage());
            return Result::error("更新失败",0);
        }
        return Result::success([]);

    }

    /**
     * 更新资讯状态
     * @param array $data
     * @return array
     */
    public function upArticleStatus(array $data):array
    {
       $result =  Article::where(['id'=>$data['id']])->update($data);
        if($result){
            return Result::success();
        }else{
            return Result::error("更新状态失败",0);
        }
    }
    /**
     * 获取新闻详情
     * @param array $data
     * @return array
     */
    public function getArticleInfo(array $data): array
    {
        $where = [
            'article.id'=>$data['id'],
            // 'article.status'=>1
        ];
        $result = Article::where($where)->leftJoin("article_data","article.id","article_data.article_id")->first();
        if(empty($result)){
            return Result::error("查询失败",0);
        }
        return Result::success($result);
    }
    /**
     *  获取头条新闻
     * @param array $data
     * @return array
    */
    public function getWebsiteArticlett(array $data): array   
    {
        // return Result::success($data['website_id']);
        $category = WebsiteCategory::where('website_id', $data['website_id'])->pluck('category_id');
        $category = array_values(array_unique($category->toArray()));
        $result = [];
        if ($category) {
            $placeid = isset($data['placeid']) && !empty($data['placeid']) ? $data['placeid'] - 1 : 0;
            $where = [
                'status' => 1,
            ];
            var_dump($data, 'data-----------------');
            // level=7  根据文章key来匹配文章
            if (isset($data['level']) && $data['level'] == 7) {
                //  根据文章id获取key
                // $data['id'] = 50142;
                if (isset($data['id']) && !empty($data['id'])) {
                    $keyword = Article::where('id', $data['id'])->value('keyword');
                    $keywordArray = explode(',', $keyword);
                    $whereL7 = [];
                    foreach ($keywordArray as $k => $v) {
                        $whereL7[] = ['keyword', 'like', '%' . $v . '%'];
                    }
                    // 原始查询
                    $result = Article::where($whereL7)
                        ->offset($placeid)
                        ->limit($data['pageSize'])
                        ->orderBy('updated_at', 'desc')
                        ->get()
                        ->map(function ($article ) use ($data) {
                            $catid = $article->catid;
                            $pinyin = '';
                            $category = WebsiteCategory::where('category_id', $catid)->where('website_category.website_id', $data['website_id'])->first();
                            if (!empty($category->aLIas_pinyin) && $category->pid != 0) {
                                $childCategory = WebsiteCategory::where('category_id', $category->pid)->where('website_category.website_id', $data['website_id'])->first();
                                if ($childCategory && !empty($childCategory->aLIas_pinyin)) {
                                    $pinyin = $childCategory->aLIas_pinyin ?  $childCategory->aLIas_pinyin.'/'. $category->aLIas_pinyin : null;
                                }
                            } else {
                                $pinyin = $category->aLIas_pinyin ?  $category->aLIas_pinyin : null;
                            }
                            $article->pinyin = $pinyin;
                            return $article;
                        });
                        if (empty($result)) {
                            return Result::success([]);
                        }
                    return Result::success($result);
                } else {
                    return Result::error("参数错误level=7,id不能为空", 0);
                }
            }
            //如果是4：最新资讯（数据库已不存在） 5：资讯推荐（数据库已不存在）；
            // 1：头条资讯；2：轮播图；6：热点资讯；（数据库）
            var_dump($where, 'where-----------------');
            $result = Article::where($where)
                ->whereIn("catid", $category)
                // ->leftJoin('website_category', 'article.catid', 'website_category.category_id')
                // ->where('website_category.website_id', $data['website_id'])
                ->where(function ($query) use ($data) {
                    $query->whereRaw("JSON_CONTAINS(ignore_ids, '" . intval($data['website_id']) . "') = 0")
                        ->orWhereNull("ignore_ids");
                })
            //$data['level'] == 4 || $data['level'] == 5 查询随机
                ->when($data['level'] == 5, function ($query) {
                    $query->inRandomOrder()
                    //updated_at最近三十天;
                        ->where('updated_at', '>', date("Y-m-d H:i:s", strtotime("-30 day")));
                })
                ->when($data['level'] == 4, function ($query) {
                    $query->orderBy("article.updated_at", "desc");
                })
                ->when(!empty($data['level']), function ($query) use ($data) {
                    if ($data['level'] != 4 && $data['level'] != 5) {
                        $query->whereRaw("JSON_CONTAINS(level, '" . intval($data['level']) . "') = 1")
                            ->orderBy("article.updated_at", "desc");
                    }
                })
                ->select('article.*')
                ->offset($placeid)
                ->limit($data['pageSize'])
                ->get()
                ->map(function ($article ) use ($data) {
                    $catid = $article->catid;
                    $pinyin = '';
                    $category = WebsiteCategory::where('category_id', $catid)->where('website_category.website_id', $data['website_id'])->first();
                    if (!empty($category->aLIas_pinyin) && $category->pid != 0) {
                        $childCategory = WebsiteCategory::where('category_id', $category->pid)->where('website_category.website_id', $data['website_id'])->first();
                        if ($childCategory && !empty($childCategory->aLIas_pinyin)) {
                            $pinyin = $childCategory->aLIas_pinyin ?  $childCategory->aLIas_pinyin.'/'. $category->aLIas_pinyin : null;
                        }
                    } else {
                        $pinyin = $category->aLIas_pinyin ?  $category->aLIas_pinyin : null;
                    }
                    $article->pinyin = $pinyin;
                    return $article;
                });
            if (empty($result)) {
                return Result::error("暂无头条新闻", 0);
            }
            return Result::success($result);
        } else {
            return Result::error("本网站下暂无相关栏目", 0);
        }
    }
    /**
     * 获取模块新闻
     * @param array $data
     * @return array
    */
   
    public function getWebsiteModelArticles(array $data): array    
    {
        $catid = $data['catid'];
        $category = WebsiteCategory::where('website_id', $data['website_id'])->where('category_id', $catid)->select('category_id')->get();
        $category = $category->toArray();
        if (!empty($category)) {
            $where = [
                'status' => 1,
                'catid' => $catid,
            ];
            $placeid = isset($data['placeid']) && !empty($data['placeid']) ? $data['placeid'] - 1 : 0;
            // 1：文字新闻；2：轮播图；3：图文；
            // 级别：0：未分类 
            // 3：推荐图片
            if ($data['level'] == 1) {
                $data['level'] = 0;
             } 
            $result = Article::where($where)
                    ->where(function ($query) use ($data) {
                        $query->whereRaw("JSON_CONTAINS(level, '" . intval($data['level']) . "') = 1")
                            ->orWhereNull("level")
                            ->orWhereRaw("level = '[]'");
                    })
                    ->where(function ($query) use ($data) {
                        $query->whereRaw("JSON_CONTAINS(ignore_ids, '" . intval($data['website_id']) . "') = 0")
                            ->orWhereNull("ignore_ids");
                    })
                    ->orderBy("updated_at", "desc")
                    ->offset($placeid)
                    ->limit($data['pagesize'])
                    ->get();
            if (empty($result)) {
                return Result::error("此栏目暂无相关新闻", 0);
            }
        } else {
            return Result::error("此网站暂无此栏目", 0);

        }
        return Result::success($result);
    }
    

    /**
     *获取新闻列表 
     * @param array $data
     * @return array
     */
    public function getWebsiteArticleList(array $data): array 
    {
        // return Result::success($data);
        $where[] = ['status', '=', 1];
        if (isset($data['catid']) && !empty($data['catid'])) {
            if (is_array($data['catid'])) {
                $category = WebsiteCategory::where('website_id', $data['website_id'])->whereIn('category_id', $data['catid'])->pluck('category_id');
                array_push($where, ['catid', 'in', $data['catid']]);
            } else {
                $category = WebsiteCategory::where('website_id', $data['website_id'])->where('category_id', $data['catid'])->pluck('category_id');
                array_push($where, ['catid', '=', $data['catid']]);
            }
            if (empty($category)) {
                return Result::error("此网站暂无此栏目", 0);
            }
        }
        // return Result::success($where);
        $rep = Article::where(function ($query) use ($where) {
            foreach ($where as $condition) {
                if ($condition[1] === 'in') {
                    $query->whereIn($condition[0], $condition[2]);
                } else {
                    $query->where($condition[0], $condition[1], $condition[2]);
                }
            }
        })
        ->where(function ($query) use ($data) {
            $query->whereRaw("JSON_CONTAINS(ignore_ids, '".intval($data['website_id'])."') = 0")
                  ->orWhereNull("ignore_ids");
        })
        ->select(
            'article.id',
            'article.title',
            'article.imgurl',
            'article.author',
            'article.updated_at',
            'article.introduce',
            'article.islink',
            'article.linkurl',
            'article.copyfrom',
            'article.catid')
        ->orderBy("updated_at", "desc")
        ->limit($data['pageSize'])
        ->offset(($data['page'] - 1) * $data['pageSize'])
        ->get()
        ->map(function ($article ) use ($data) {
            $catid = $article->catid ?? 0;
            $pinyin = '';
            $category = WebsiteCategory::where('category_id', $catid)->where('website_category.website_id', $data['website_id'])->first();
            $pinyin = $category->aLIas_pinyin ? $category->aLIas_pinyin : null;
            if ($category->pid != 0 && !empty($category->aLIas_pinyin)) {
                $childCategory = WebsiteCategory::where('category_id', $category->pid)->where('website_category.website_id', $data['website_id'])->first();
                $pinyin = $childCategory->aLIas_pinyin ?  $childCategory->aLIas_pinyin.'/'. $category->aLIas_pinyin : null;
            }
            $article->pinyin = $pinyin;
            return $article;
            });

        $count = Article::where(function ($query) use ($where) {
            foreach ($where as $condition) {
                if ($condition[1] === 'in') {
                    $query->whereIn($condition[0], $condition[2]);
                } else {
                    $query->where($condition[0], $condition[1], $condition[2]);
                }
            }
        })->count();

        $data = [
            'rows' => $rep->toArray(),
            'count' => $count,
        ];

        if (empty($rep)) {
            return Result::error("没有信息数据");
        }
        return Result::success($data);
        
    }
    /**
     * 前端-获取新闻详情
     * @param array $data
     * @return array
     */
    public function selectWebsiteArticleInfo(array $data): array
    {
        $where = [
            'article.id'=>$data['id'],
            'article.status'=>1
        ];
        $result = Article::where($where)->leftJoin("article_data","article.id","article_data.article_id")
        ->where(function ($query) use ($data) {
            $query->whereRaw("JSON_CONTAINS(ignore_ids, '".intval($data['website_id'])."') = 0")
                  ->orWhereNull("ignore_ids");
        })
        ->first();
        if(empty($result)){
            return Result::error("暂无此新闻！",0);
        }
        $category = WebsiteCategory::where('website_id',$data['website_id'])->where(['category_id'=>$result['catid']])->first();
        if(empty($category)){
            return Result::error("查询失败",0);
        }
        $result['category_id'] = $category['category_id'];
        $result['cat_name'] = $category['alias'];
        return Result::success($result);
    }
    /**
     * 前端-获取网站调查问卷
     * @param array $data
     * @return array
     */
     public function getWebsiteSurvey(array $data): array
    {
        if(isset($data['website_id']) && !empty($data['website_id'])){
            $website = Website::where('id',$data['website_id'])->first();
            if(empty($website)){
                return Result::error("暂无此网站",0);
            }
        }
        if(isset($data['art_id'])  && !empty($data['art_id'])){
            $article = Article::where('id',$data['art_id'])->where('status',1)->first();
            if(empty($article)){
                return Result::error("暂无此文章",0);
            }
            // return Result::error($data,0);
            $where['art_id'] = $data['art_id'];
            // $query = ArticleSurvey::where('art_id',$data['art_id']); 
            
        }else{
            $survey = Article::where(function ($query) {
                $query->whereRaw("JSON_CONTAINS(cat_arr_id, '28')")
                      ->orWhereRaw("JSON_CONTAINS(cat_arr_id, '\"28\"')");
            })
            ->where('status',1)
            ->where('is_survey',1)
            ->select('survey_id')
            ->orderBy('updated_at','desc')
            ->first();
            if(empty($survey)){
                return Result::error("暂无调查问卷",0); 
            }
            $where['sur_id'] = $survey['survey_id'];
            // $query = ArticleSurvey::where('sur_id',$survey['sur_id']);
        }
        // return Result::success($where);
        $result =  ArticleSurvey::where($where)
            ->where(function ($query) {
                $query->where('is_other', 0)
                      ->orWhere(function ($subQuery) {
                          $subQuery->where('is_other', 1)
                                   ->where('other_id', 0);
                      });
            })
            ->leftJoin('article', 'article_survey.art_id', 'article.id')
            ->select('article_survey.*', 'article.survey_type')
            ->get()->all();
        if(empty($result)){
            return Result::error("此文章暂无调查问卷",0); 
        }
        return Result::success($result);
    }
    /**
     * 前端-添加网站调查问卷选项
     * @param array $data
     * @return array
     */
    public function addWebsiteSurveyOption(array $data): array
    {
        if(isset($data['website_id']) && !empty($data['website_id'])){
            $website = Website::where('id',$data['website_id'])->first();
            if(empty($website)){
                return Result::error("暂无此网站",0);
            }
            if(isset($data['sur_id']) && !empty($data['sur_id'])){
                $survey = ArticleSurvey::where('sur_id',$data['sur_id'])->where('website_id',$data['website_id'])->where('is_other',1)->where('other_id',0)->first(); 
                if(empty($survey)){
                    return Result::error("此调查问卷不可添加选项",0); 
                }
                if(isset($data['choice_name']) &&!empty($data['choice_name'])){
                    $choice = [
                        'art_id'=>$survey['art_id'],
                        'website_id'=>$data['website_id'],
                        'survey_name'=>$survey['survey_name'],
                        'choice_name'=>$data['choice_name'],
                        'sur_id'=>$survey['sur_id'],                   
                        'is_other'=>1,
                        'other_id'=>$survey['id'],
    
                    ];
                    $result = ArticleSurvey::insertGetId($choice);
                    if(empty($result)){
                        return Result::error("添加失败",0);
                    }
                    return Result::success($result);
                }
            }
            return Result::error("添加失败",0);
        }
        return Result::error("添加失败",0);
        
    }
    /**
     * 前端-调查问卷投票   
     * @param array $data
     * @return array
     */
    public function addWebsiteSurveyVote(array $data): array
    {
        // return Result::success($data);
        if(isset($data['website_id']) && !empty($data['website_id'])){
            $website = Website::where('id',$data['website_id'])->first(); 
            if(empty($website)){
                return Result::error("暂无此网站",0); 
            }
            if(isset($data['sur_id']) && !empty($data['sur_id'])){
                $is_survey = ArticleSurvey::where('sur_id',$data['sur_id'])->first();
                // return Result::success($survey);
                if(empty($is_survey)){
                    return Result::error("此调查问卷不存在",0);
                }
                // return Result::success($survey);
                // 调查问卷类型   
                if(isset($data['choice_id']) &&!empty($data['choice_id'])){
                    //多选 若是json型则转化成数组类型
                    if (strpos($data['choice_id'], '[') === 0) {
                        $data['choice_id'] = json_decode($data['choice_id'], true);
                    } else {
                        // 单选  也转换成数组
                        $data['choice_id'] = [$data['choice_id']];
                    }
                    $data['choice_id'] = array_map('intval', $data['choice_id']);
                    $other = ArticleSurvey::whereIn('id',$data['choice_id'])
                    ->where('website_id',$data['website_id'])
                    ->where('is_other',1)
                    ->where('other_id',0)
                    ->first();
                    if(!empty($other)){
                        return Result::error("请选择已有的选项！",0);
                    }
                    $choice['other'] = ArticleSurvey::whereIn('id',$data['choice_id'])
                    ->where('website_id',$data['website_id'])
                    ->where('is_other',1)
                    ->where('other_id','!=',0)
                    ->first();
                    // return Result::success($choice['other']);
                    $choice_id = $data['choice_id'];
                    if(!empty($choice['other'])){
                        // array_push($data['choice_id'],$choice['other']['other_id']);
                        if(!empty($choice_id)){
                            $key = array_search($choice['other']['id'], $choice_id);
                            if ($key!== false) {
                                unset($choice_id[$key]);
                                $choice_id = array_values($choice_id);
                            }
                            array_push($choice_id,$choice['other']['other_id']);
                        }else{
                            $choice_id[0] = $choice['other']['other_id'];
                        }
                        array_push($data['choice_id'],$choice['other']['other_id']);
                    }
                    // return Result::success($data);
                    $choice = ArticleSurvey::whereIn('id',$data['choice_id'])
                    ->where('website_id',$data['website_id'])
                    ->increment('results', 1);                 
                    if(empty($choice)){
                        return Result::error("请选择已有的选项！",0);
                    }
                    $survey['data'] = ArticleSurvey::where('sur_id',$data['sur_id'])
                    ->where('website_id',$data['website_id'])
                    ->where('other_id', 0)
                    ->get();
                    $survey['choice'] = $choice_id;
                    return Result::success($survey);
                }
                return Result::error("参数必填！"); 
            }
            return Result::error("此调查问卷不存在",0);
        }
        return Result::error("参数必填！");
    }
    /**
     * 后端-获取网站调查问卷列表
     * @param array $data
     * @return array
     */
    public function getSurveyList(array $data): array
    {
        $where = [];
        if(isset($data['survey_name']) &&!empty($data['survey_name'])){
            array_push($where,['survey_name','like','%'.$data['survey_name'].'%']);
        }
        if(isset($data['survey_type']) && $data['survey_type'] != null){
            array_push($where,['survey_type','=',$data['survey_type']]);
        }
        if(isset($data['is_survey']) && $data['is_survey'] != null){
            array_push($where,['is_survey','=',$data['is_survey']]);
        }
        // return Result::success($where);
        
        if (!empty($where)) {
            $query = Article::where($where)->where(function ($q) {
                $q->whereNotNull('survey_name')->where('survey_name', '!=', '');
            });
        } else {
            $query = Article::where(function ($q) {
                $q->whereNotNull('survey_name')->where('survey_name', '!=', '');
            });
        }
        
        $count = $query->count();
        $survey = $query->orderByDesc('id')
        ->limit($data['pageSize'])
        ->offset(($data['page']-1)*$data['pageSize'])
        ->get();
        if(empty($survey->toArray())){
            return Result::error("暂无调查问卷!",0);
        }
        $result = [
            'rows'=>$survey,
            'count'=>$count
        ];
        return Result::success($result);
    }
    /**
     * 后端-获取网站调查问卷详情
     * @param array $data
     * @return array 
     */
    public function getSurveyInfo(array $data): array
    {
        if(isset($data['sur_id']) &&!empty($data['sur_id'])){
            $where = [ 'sur_id'=>$data['sur_id']];
            $choose =  ArticleSurvey::where($where)->where('is_other',0)
            ->leftJoin('article','article_survey.art_id','article.id')
            ->select('article_survey.*','article.survey_type')
            ->get()->all();
            if(empty($choose)){
                return Result::error("此调查问卷不存在",0);
            }
            $resultsArray  = array_column($choose, 'results');
            $total = array_sum($resultsArray);
            $other = ArticleSurvey::where($where)->where('is_other',1)->where('other_id',0)->first();
            $others = ArticleSurvey::where($where)->where('is_other',1)->where('other_id','!=',0)->orderByDesc('created_at')->get()->all();
            // $total = 0;
            if(!empty($other)){
                $total = $total + $other['results'];
                $other['choice_name'] ='(其他)';
                if(!empty($others)){
                    $other['hasChildren'] = true;
                    // array_push($other,['hasChildren','=',true]);
                    $other['children'] = $others;
                    $other_choices = [$other->toArray()];
                    $mer_choice = array_merge($choose,$other_choices);
                    $value_choice = array_values($mer_choice);
                }
                else{
                    // return Result::error('1111');
                    $other_choices = [$other->toArray()];
                    $other_choices = array_merge($choose,$other_choices);
                    $value_choice = array_values($other_choices);
                    // return Result::success($result);
                }
            }else{
                $value_choice = $choose;
            }
            $result = [
                'choose'=>$value_choice,
                'total'=>$total 
            ];
        }
        return Result::success($result);
    }

     /**
     * 前端-搜索新闻列表
     * @param array $data
     * @return array
     */
    public function selectWebsiteArticle(array $data): array
    {
        $where = [];
        // 初始化查询构造器
        $category = WebsiteCategory::where('website_id', $data['website_id'])->pluck('category_id');
        $query = Article::where('status', 1)
            ->whereIn('catid', $category)
            ->where(function ($query) use ($data) {
                $query->where(function ($subQuery) use ($data) {
                    $subQuery->whereRaw("JSON_CONTAINS(ignore_ids, '" . intval($data['website_id']) . "') = 0");
                })->orWhereNull("ignore_ids");
            });
        // return Result::success($all_articles);
        // 检查是否存在 cityid 参数
        if (isset($data['cityid']) && !empty($data['cityid'])) {
            $query->whereRaw("JSON_CONTAINS(city_arr_id, '" . intval($data['cityid']) . "')");
        }
        // 检查是否存在 department_id 参数
        if (isset($data['department_id']) && !empty($data['department_id'])) {
            $query->whereRaw("JSON_CONTAINS(department_arr_id, '" . intval($data['department_id']) . "')");
        }
        // 检查是否存在 keyword 参数
        if (isset($data['keyword']) && !empty($data['keyword'])) {
            $query->where('title', 'like', '%' . $data['keyword'] . '%');
        }
        // 计算总数
        $count = $query->count();
        // 分页查询
        $articles = $query
            ->select(
                'article.id',
                'article.title',
                'article.imgurl',
                'article.author',
                'article.updated_at',
                'article.introduce',
                'article.islink',
                'article.linkurl',
                'article.copyfrom',
                'article.catid',
                'article.department_arr_id',
                'article.city_arr_id',)
            ->orderBy("updated_at", "desc")
            ->offset(($data['page'] - 1) * $data['pageSize'])
            ->limit($data['pageSize'])
            ->get()
            ->map(function ($article ) use ($data) {
                $catid = $article->catid ?? 0;
                $pinyin = '';
                $category = WebsiteCategory::where('category_id', $catid)->where('website_category.website_id', $data['website_id'])->first();
                $pinyin = $category->aLIas_pinyin ? $category->aLIas_pinyin : null;
                if ($category->pid != 0 && !empty($category->aLIas_pinyin)) {
                    $childCategory = WebsiteCategory::where('category_id', $category->pid)->where('website_category.website_id', $data['website_id'])->first();
                    $pinyin = $childCategory->aLIas_pinyin ?  $childCategory->aLIas_pinyin.'/'. $category->aLIas_pinyin : null;
                }
                $article->pinyin = $pinyin;
                return $article;
                });
        if (empty($articles)) {
            return Result::error("没有符合条件的资讯数据");
        }
        $data = [
            'rows' => $articles,
            'count' => $count,
        ];
        return Result::success($data);
    }

    
    /**
     * 模块新闻加强版 
     * @param array $data
     * @return array
    */
    public function getWebsiteCatidArticle(array $data): array
    {
        // return Result::success($data);
        $where = [
            // 'category.status' => 1,
            'website_category.category_id' => $data['catid'],
            'website_category.website_id' => $data['website_id'],
            // 'article.status' => 1,
        ];
        // $category = WebsiteCategory::where($where);
        if(isset($data['child_catnum']) && !empty($data['child_catnum'])){
            $child_catnum = $data['child_catnum']?? 1;
            $category['child'] = WebsiteCategory::where('pid',$data['catid'])->where('website_id',$data['website_id'])->select('category_id','alias')->limit($child_catnum)->get()->toArray();
            $childCategoryIds = array_column($category['child'], 'category_id');
            if(empty($childCategoryIds)){
                return Result::error("暂无子栏目",0);
            }
            $imgArticles = [];
            $textArticles = [];
            // return Result::success($childCategoryIds);
            if(isset($data['child_imgnum']) && !empty($data['child_imgnum']) && $data['child_imgnum']!=0){
                // 初始化子分类图片新闻和文字新闻数组
                
                // 查询所有子级栏目的图文新闻
                $imgArticles = Article::where('catid', $childCategoryIds[0])
                    ->where(function ($query) use ($data) {
                        $query->where(function ($subQuery) use ($data) {
                            $subQuery->whereRaw("JSON_CONTAINS(ignore_ids, '".intval($data['website_id'])."') = 0");
                        })->orWhereNull("ignore_ids");
                    })
                    ->where('status', 1)
                    ->where('imgurl', '!=', '')
                    ->select('*')
                    ->orderBy('updated_at', 'desc')
                    ->limit($data['child_imgnum'])
                    ->get();
            }
            if( isset($data['child_textnum']) && !empty($data['child_textnum']) && $data['child_textnum']!=0){
                // 查询所有子级栏目的文字新闻
                $textArticles = Article::where('catid', $childCategoryIds[0])
                    ->where('status', 1)
                    ->where(function ($query) use ($data) {
                        $query->where(function ($subQuery) use ($data) {
                            $subQuery->whereRaw("JSON_CONTAINS(ignore_ids, '".intval($data['website_id'])."') = 0");
                        })->orWhereNull("ignore_ids");
                    })
                    // ->where(function ($query) {
                    //     $query->whereNull('imgurl')
                    //         ->orWhere('imgurl', '');
                    // })
                    ->select('*')
                    ->orderBy('updated_at', 'desc')
                    ->limit($data['child_textnum'])
                    ->get();
            }
            // 遍历子分类，将图文新闻和文字新闻分别添加到子分类中
            $category['child'] = array_map(function ($child) use ($imgArticles, $textArticles) {
                $child['img'] = $imgArticles? $imgArticles->where('catid', $child['category_id']) : [];
                $child['text'] = $textArticles? $textArticles->where('catid', $child['category_id']) : [];
                return $child;
            }, $category['child']);
            
        }
        // }
        if (isset($data['img_num']) && !empty($data['img_num'])) {
            $category['img'] = WebsiteCategory::where($where)
                ->leftJoin('article', 'article.catid', 'website_category.category_id')
                ->where('article.status', 1)
                ->where('article.imgurl', '!=', '')
                ->select('article.*','website_category.category_id','website_category.alias')
                ->orderBy('article.updated_at', 'desc')
                ->limit($data['img_num'])
                ->get();
        }

        if (isset($data['text_num']) && !empty($data['text_num'])) {
            $category['text'] = WebsiteCategory::where($where)
                ->leftJoin('article', 'article.catid', 'website_category.category_id')
                ->where('article.status', 1)
                // ->where(function ($query) {
                //     $query->whereNull('article.imgurl')
                //           ->orWhere('article.imgurl', '');
                // })
                ->select('article.*','website_category.category_id','website_category.alias')
                ->orderBy('article.updated_at', 'desc')
                ->limit($data['text_num'])
                ->get();
        }

        // $category = $category->get();
      
        if(empty($category)){
            return Result::error("查询失败", 0);
        }
        return Result::success($category);
    }
     /**
     * 模块新闻加强plus版 
     * @param array $data
     * @return array
    */
    public function getWebsiteAllArticle(array $data): array
    {
        // 修正传入的字符串，将单引号替换为双引号
        $input['id'] = $data['id'];
        $input['website_id'] = $data['website_id'];
        // 将 JSON 字符串转换为 PHP 数组
        $data = json_decode($input['id'], true);
        // 使用 array_map 处理每个元素
        $result = array_map(function ($item) use ($input) {
            list($parentCatId, $parentImgNum, $parentTextNum) = explode(',', $item['parent']);
            $website = [
                'website_id' => $input['website_id'],
            ];
            // 查询栏目名称
            $category = WebsiteCategory::where('category_id', $parentCatId)->where($website)->first(['alias', 'category_id','aLIas_pinyin']);
            if(empty($category)){
                $imgArticles = [];
                $textArticles = [];
                // return Result::error("暂无此栏目",0);
            }else{
                $parent_alias = $category->alias ?? '';
                $parent_pinyin = $category->aLIas_pinyin ? $category->aLIas_pinyin : null;
                // 查询图片新闻
                $imgArticles = Article::where('catid', $parentCatId)
                ->where('status', 1)
                ->where(function ($query) use ($website) {
                    $query->where(function ($subQuery) use ($website) {
                        $subQuery->whereRaw("JSON_CONTAINS(ignore_ids, '".intval($website['website_id'])."') = 0");
                    })->orWhereNull("ignore_ids");
                })
                ->where('imgurl', '!=', '')
                ->select(
                    'article.id',
                    'article.title',
                    'article.imgurl',
                    'article.author',
                    'article.updated_at',
                    'article.introduce',
                    'article.islink',
                    'article.linkurl',
                    'article.copyfrom',
                    DB::raw("'$parent_pinyin' as pinyin") // 添加 pinyin 字段
                )
                ->orderBy('updated_at', 'desc')
                ->limit($parentImgNum)
                ->get()->all();

                // 查询文字新闻
                $textArticles = Article::where('catid', $parentCatId)
                    ->where('status', 1)
                    ->where(function ($query) use ($website) {
                        $query->where(function ($subQuery) use ($website) {
                            $subQuery->whereRaw("JSON_CONTAINS(ignore_ids, '".intval($website['website_id'])."') = 0");
                        })->orWhereNull("ignore_ids");
                    })
                    ->select(
                        'article.id',
                        'article.title',
                        'article.author',
                        'article.updated_at',
                        'article.introduce',
                        'article.islink',
                        'article.linkurl',
                        'article.copyfrom',
                         DB::raw("'$parent_pinyin' as pinyin"))
                    ->orderBy('updated_at', 'desc')
                    ->limit($parentTextNum)
                    ->get()->all();
            }
            $resultItem = [
                'alias' => $parent_alias,
                'category_id' => $parentCatId,
                'pinyin' => $parent_pinyin,
                'imgnum' => $imgArticles,
                'textnum' => $textArticles,
                
            ];

            if (!empty($item['child']) && $item['child'] != "") {
                $parent_pinyin_str = is_string($parent_pinyin) ? $parent_pinyin.'/' : '';
                $childCategory = WebsiteCategory::where('pid', $parentCatId)->where($website)
                    ->selectRaw("category_id, alias, CONCAT( ?, aLIas_pinyin) as aLIas_pinyin", [$parent_pinyin_str])
                    ->get()->all();
                if ($childCategory) {
                    list($childCatId, $childImgNum, $childTextNum) = explode(',', $item['child']);
                    // 查询子栏目名称
                $childCategoryInfo = WebsiteCategory::where('category_id', $childCatId)->where($website)
                    ->selectRaw("category_id, alias, CONCAT( ?, aLIas_pinyin) as aLIas_pinyin", [$parent_pinyin_str])
                    ->first();
                $child_pinyin = $childCategoryInfo->aLIas_pinyin ? $childCategoryInfo->aLIas_pinyin : null;
                    if(empty($childCategoryInfo)){
                        $childImgArticles = [];
                        $childTextArticles = [];
                    }else{
                         // 查询子栏目图片新闻
                        $childImgArticles = Article::where('catid', $childCatId)
                            ->where('status', 1)
                            ->where(function ($query) use ($website) {
                                $query->where(function ($subQuery) use ($website) {
                                    $subQuery->whereRaw("JSON_CONTAINS(ignore_ids, '".intval($website['website_id'])."') = 0");
                                })->orWhereNull("ignore_ids");
                            })
                            ->select(
                                'article.id',
                                'article.title',
                                'article.imgurl',
                                'article.author',
                                'article.updated_at',
                                'article.introduce',
                                'article.islink',
                                'article.linkurl',
                                'article.copyfrom',
                                DB::raw("'$child_pinyin' as pinyin"))
                            ->where('imgurl', '!=', '')
                            ->orderBy('updated_at', 'desc')
                            ->limit($childImgNum)
                            ->get()->all();
                        // 查询子栏目文字新闻
                        $childTextArticles = Article::where('catid', $childCatId)
                            ->where('status', 1)
                            ->where(function ($query) use ($website) {
                                $query->where(function ($subQuery) use ($website) {
                                    $subQuery->whereRaw("JSON_CONTAINS(ignore_ids, '".intval($website['website_id'])."') = 0");
                                })->orWhereNull("ignore_ids");
                            })
                            ->select(
                                'article.id',
                                'article.title',
                                'article.author',
                                'article.updated_at',
                                'article.introduce',
                                'article.islink',
                                'article.linkurl',
                                'article.copyfrom',
                                DB::raw("'$child_pinyin' as pinyin"))
                            ->orderBy('updated_at', 'desc')
                            ->limit($childTextNum)
                            ->get()->all();
                    }
                    $resultItem['child'] = [
                        'alias' => $childCategoryInfo ? $childCategoryInfo->alias : null,
                        'category_id' => $childCatId,
                        'pinyin' => $childCategoryInfo->aLIas_pinyin ?? '',
                        'all_childcat' => $childCategory,
                        'imgnum' => $childImgArticles,
                        'textnum' => $childTextArticles,
                        
                    ];
                    // $resultItem['pinyin'] = $childCategoryInfo->aLIas_pinyin ?? '';
                }
            }

            return $resultItem;
        }, $data);
        return Result::success($result);
                // return Result::success($data);
    }


    /**
     * 乡村网-获取特殊新闻模块
     * @param array $data
     * @return array
     */
    public function getWebsiteArticles(array $data): array
    {
        $input['id'] = $data['id']; 
        $input['website_id'] = $data['website_id']; 
        $data = json_decode($input['id'], true); 
        // 使用 array_map 处理每个元素 
        $result = array_map(function ($item) use ($input) { 
            list($parentCatId, $parentImgNum, $parentTextNum) = explode(',', $item['parent']); 
            $website = [ 
                'website_id' => $input['website_id']
            ]; 
            // 查询栏目名称 
            $category = WebsiteCategory::where('category_id', $parentCatId)->where($website)->first(['alias', 'category_id','aLIas_pinyin']); 
            $pinyin = $category->aLIas_pinyin ? $category->aLIas_pinyin : null;
            if(empty($category)){ 
                $imgArticles = []; 
                $textArticles = []; 
                // return Result::error("暂无此栏目",0); 
            }else{ 
                $child_category = WebsiteCategory::where('pid', $parentCatId)->where($website)->pluck('category_id')->toArray();
                $parent_alias = $category->aLIas_pinyin ? $category->aLIas_pinyin.'/' : null;
                // return Result::success($website);
                // 查询图片新闻 
                // 合并查询条件
                $baseQuery = Article::where(function ($query) use ($website) {
                        $query->where(function ($subQuery) use ($website) {
                            $subQuery->whereRaw("JSON_CONTAINS(ignore_ids, '" . intval($website['website_id']) . "') = 0");
                        })->orWhereNull("ignore_ids");
                    })
                    ->where('website_category.website_id', $website['website_id'])
                    ->where('article.status', 1)
                    ->leftJoin('website_category', 'website_category.category_id', 'article.catid');
                    
                 // 查询文字新闻
                 $textArticles = clone $baseQuery;
                 $textArticles = $textArticles->whereIn('catid',$child_category)
                 ->select(
                    'article.id',
                    'article.title',
                    // 'article.imgurl',
                    'article.author',
                    'article.updated_at',
                    'article.introduce',
                    'article.islink',
                    'article.linkurl',
                    'article.copyfrom',
                    'website_category.category_id',
                    'website_category.alias',
                    'website_category.aLIas_pinyin'
                )
                ->selectRaw("CONCAT(?, aLIas_pinyin) as aLIas_pinyin", [$parent_alias])
                ->orderBy('article.updated_at', 'desc')
                ->limit($parentTextNum)
                ->get()
                ->all();
                 if(empty($textArticles)){
                    $textArticles = clone $baseQuery;
                    $textArticles = $textArticles->where('catid',$parentCatId)
                    ->select(
                        'article.id',
                        'article.title',
                        // 'article.imgurl',
                        'article.author',
                        'article.updated_at',
                        'article.introduce',
                        'article.islink',
                        'article.linkurl',
                        'article.copyfrom',
                        'website_category.category_id',
                        'website_category.alias',
                        'website_category.aLIas_pinyin'
                    )
                    ->selectRaw("CONCAT(?, aLIas_pinyin) as aLIas_pinyin", [$parent_alias])
                    ->orderBy('article.updated_at', 'desc')
                    ->limit($parentTextNum)
                    ->get()
                    ->all();
                }
                // 查询图片新闻
                $imgArticles = clone $baseQuery;
                $imgArticles = $imgArticles->where('imgurl', '!=', '')->whereIn('catid',$child_category)
                ->select(
                    'article.id',
                    'article.title',
                    'article.imgurl',
                    'article.author',
                    'article.updated_at',
                    'article.introduce',
                    'article.islink',
                    'article.linkurl',
                    'article.copyfrom',
                    'website_category.category_id',
                    'website_category.alias',
                    'website_category.aLIas_pinyin'
                )
                ->selectRaw("CONCAT(?, aLIas_pinyin) as aLIas_pinyin", [$parent_alias])
                ->orderBy('article.updated_at', 'desc')
                ->limit($parentImgNum)
                ->get()
                ->all();
                if(empty($imgArticles)){
                    $imgArticles = clone $baseQuery;
                    $imgArticles = $imgArticles->where('imgurl', '!=', '')->where('catid',$parentCatId)
                    ->select(
                            'article.id',
                            'article.title',
                            'article.imgurl',
                            'article.author',
                            'article.updated_at',
                            'article.introduce',
                            'article.islink',
                            'article.linkurl',
                            'article.copyfrom',
                            'website_category.category_id',
                            'website_category.alias',
                            'website_category.aLIas_pinyin'
                        )
                        ->selectRaw("CONCAT(?, aLIas_pinyin) as aLIas_pinyin", [$parent_alias])
                        ->orderBy('article.updated_at', 'desc')
                        ->limit($parentImgNum)
                        ->get()
                        ->all(); 
                }
               
            }
            $resultItem = [ 
                'alias' => $category ? $category->alias : null, 
                'category_id' => $parentCatId, 
                'pinyin' => $pinyin ? $pinyin : null, 
                'imgnum' => $imgArticles ?? [], 
                'textnum' => $textArticles ?? [], 
                
            ]; 


            return $resultItem; 
        }, $data); 
        return Result::success($result); 

    }
     /**
     *获取头条类新闻模块-合集
     * @param array $data
     * @return array
     */
    public function getWebsiteAllArticlett(array $data): array
    {
        $input['id'] = $data['id'];
        $input['website_id'] = $data['website_id'];
        $data = json_decode($input['id'], true);
        // 使用 array_map 处理每个元素
        $result = array_map(function ($item) use ($input) { 
            list($parentCatId, $parentImgNum, $parentTextNum) = explode(',', $item['parent']);  
            $website = [
                'website_id' => $input['website_id'] 
            ];
            $category = WebsiteCategory::where('website_id', $input['website_id'])->pluck('category_id');
            $category = array_values(array_unique($category->toArray()));
            $placeid = isset($data['placeid']) && !empty($data['placeid']) ? $data['placeid'] - 1 : 0;
            $where = [
                'status' => 1,
            ];

            return $category;
        }, $data); // 添加第二个参数 $data，确保 array_map 函数有两个参数
           
        return Result::success($result);
    }


}